@@ -2,6 +2,7 @@
 //  TKChartData.h
 //
 //  Copyright (c) 2013 Telerik. All rights reserved.
+#import "TKChartAxis.h"
 
 /**
  * @discussion Represents a data provider protocol for chart's series
@@ -62,4 +63,9 @@
  */
 @property (nonatomic, strong, readonly) id signalYValue;
 
+/**
+ Returns a string representation of the current implementation.
+ */
+-(NSString*) generateStringRepresentationForXAxis:(TKChartAxis *)xAxis yAxis:(TKChartAxis *)yAxis;
+
 @end
